package org.ow2.util.ee.metadata.common.impl.configurator;

import java.util.Map;

import org.ow2.util.ee.metadata.common.api.interfaces.ISharedMetadata;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxAnnotationResourceVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxEjbEJBVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxPersistencePersistenceContextVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxPersistencePersistenceUnitVisitor;
import org.ow2.util.scan.api.IAnnotationVisitor;

/**
 * Utility class.
 * @author Gael Lalire
 */
public final class CommonMetadataConfigurator {

    /**
     * Constructor.
     */
    private CommonMetadataConfigurator() {
    }

    /**
     * @param <T> type
     * @param annotationVisitors annotationVisitors
     * @param annotationMetadata am
     */
    public static <T extends ISharedMetadata> void initVisitor(final Map<String, IAnnotationVisitor> annotationVisitors,
            final T annotationMetadata) {

        // add @EJB
        annotationVisitors.put(JavaxEjbEJBVisitor.TYPE, new JavaxEjbEJBVisitor<T>(annotationMetadata));

        // add @Resource
        annotationVisitors.put(JavaxAnnotationResourceVisitor.TYPE, new JavaxAnnotationResourceVisitor<T>(annotationMetadata));

        // add @PersistenceContext
        annotationVisitors.put(JavaxPersistencePersistenceContextVisitor.TYPE, new JavaxPersistencePersistenceContextVisitor<T>(
                annotationMetadata));

        // add @PersistenceUnit
        annotationVisitors.put(JavaxPersistencePersistenceUnitVisitor.TYPE, new JavaxPersistencePersistenceUnitVisitor<T>(
                annotationMetadata));

    }

}
